import commands
import os.path
#!/usr/bin/python
# coding: UTF-8
# Rec10 TS Recording Tools
# Copyright (C) 2009-2010 Yukikaze
import os
import configreader
import recdblist
def wav2aac_nero(pin,pout):
    os.environ['LANG']="ja_JP.UTF-8"
    neroaac=configreader.getpath('NeroAAC')
    exe=neroaac+" -br 128000 -2pass -if \""+pin+"\" -of \""+pout+"\""
    txt=u"Cmd : "+exe+"\n"
    try:
        txt=txt+commands.getoutput(exe.encode('utf-8'))
        recdblist.addlog(pin, txt, "Wav2aac_Nero log")
    except:
        if not os.path.exists(pout):
            lame="lame"
            exe=lame+" -b 128 \""+pin+"\" \""+pout+"\""
            txt=u"Cmd : "+exe+"\n"
            txt=txt+commands.getoutput(exe.encode('utf-8'))
            recdblist.addlog(pin, txt, "Wav2aac_Lame log")
def wav2mp3_lame(pin,pout):
    os.environ['LANG']="ja_JP.UTF-8"
    lame="lame"
    exe=lame+" -b 128 \""+pin+"\" \""+pout+"\""
    txt=u"Cmd : "+exe+"\n"
    try:
        txt=txt+commands.getoutput(exe.encode('utf-8'))
    except:
        ""
    recdblist.addlog(pin, txt, "Wav2aac_Lame log")